@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #pragma once
 
 #include <Akonadi/Item>
-#include <Akonadi/KMime/MarkAsCommand>
+#include <Akonadi/MarkAsCommand>
 #include <QObject>
 #include <QPixmap>
 #include <QStringList>
