@@ -2,7 +2,7 @@
   This file is part of libkldap.
 
   SPDX-FileCopyrightText: 2002-2009 Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -39,9 +39,7 @@ KCMLdap::KCMLdap(QWidget *parent, const QVariantList &)
     connect(mLdapConfigureWidget, &KLDAP::LdapConfigureWidget::changed, this, qOverload<bool>(&KCMLdap::changed));
 }
 
-KCMLdap::~KCMLdap()
-{
-}
+KCMLdap::~KCMLdap() = default;
 
 void KCMLdap::load()
 {
