@@ -7,8 +7,8 @@
 #pragma once
 
 #include "ewsjob.h"
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 class EwsClient;
 class EwsItem;
