@@ -20,10 +20,10 @@
 #include <noinferiorsattribute.h>
 #include <noselectattribute.h>
 
-#include <Akonadi/KMime/MessageParts>
+#include <Akonadi/MessageParts>
 
+#include <Akonadi/BlockAlarmsAttribute>
 #include <Akonadi/CachePolicy>
-#include <Akonadi/Calendar/BlockAlarmsAttribute>
 #include <Akonadi/CollectionColorAttribute>
 #include <Akonadi/CollectionIdentificationAttribute>
 #include <Akonadi/EntityDisplayAttribute>
@@ -192,9 +192,7 @@ KolabRetrieveCollectionsTask::KolabRetrieveCollectionsTask(const ResourceStateIn
     mRequestedMetadata << "/shared" KOLAB_COLOR_ANNOTATION << "/private" KOLAB_COLOR_ANNOTATION;
 }
 
-KolabRetrieveCollectionsTask::~KolabRetrieveCollectionsTask()
-{
-}
+KolabRetrieveCollectionsTask::~KolabRetrieveCollectionsTask() = default;
 
 void KolabRetrieveCollectionsTask::doStart(KIMAP::Session *session)
 {
